@@ -1,10 +1,10 @@
-use crate::{Options, NS as GLOBAL_NS};
+use crate::{options, NS as GLOBAL_NS};
 
 fn ns() -> String {
     format!("{}__comment", GLOBAL_NS)
 }
 
-pub fn comment(options: &Options) -> String {
+pub fn comment() -> String {
     format!(
         "
 // Comment
@@ -14,9 +14,9 @@ const {loc_blob} *{fn_attributes} {ns}__get_location(const {comment_blob} *self_
 const {comment_type_blob} *{fn_attributes} {ns}__get_kind(const {comment_blob} *self_blob);
 ",
         ns = ns(),
-        fn_attributes = options.fn_attributes,
-        comment_blob = options.comment_blob_name,
-        loc_blob = options.loc_blob_name,
-        comment_type_blob = options.comment_type_blob_name,
+        fn_attributes = options().fn_attributes,
+        comment_blob = options().comment_blob_name,
+        loc_blob = options().loc_blob_name,
+        comment_type_blob = options().comment_type_blob_name,
     )
 }
