@@ -1,9 +1,9 @@
-use crate::{Options, NS as GLOBAL_NS};
+use crate::{options, NS as GLOBAL_NS};
 
 fn ns() -> String {
     format!("{}__comment_type", GLOBAL_NS)
 }
-pub fn comment_type(options: &Options) -> String {
+pub fn comment_type() -> String {
     format!(
         "
 // CommentType
@@ -16,7 +16,7 @@ bool {fn_attributes} {ns}__is_document(const {comment_type_blob} *self_blob);
 bool {fn_attributes} {ns}__is_unknown(const {comment_type_blob} *self_blob);
 ",
         ns = ns(),
-        fn_attributes = options.fn_attributes,
-        comment_type_blob = options.comment_type_blob_name
+        fn_attributes = options().fn_attributes,
+        comment_type_blob = options().comment_type_blob_name
     )
 }
