@@ -1,10 +1,10 @@
-use crate::{Options, NS as GLOBAL_NS};
+use crate::{options, NS as GLOBAL_NS};
 
 fn ns() -> String {
     format!("{}__decoded_input", GLOBAL_NS)
 }
 
-pub fn decoded_input(options: &Options) -> String {
+pub fn decoded_input() -> String {
     format!(
         "
 // DecodedInput
@@ -23,10 +23,10 @@ void {fn_attributes} {ns}__set_bytes({decoded_input_blob} *self_blob, {byte_list
 {byte_list_blob} {fn_attributes} {ns}__take_bytes({decoded_input_blob} *self_blob);
 ",
         ns = ns(),
-        fn_attributes = options.fn_attributes,
-        decoded_input_blob = options.decoded_input_blob_name,
-        string_ptr_blob = options.string_ptr_blob_name,
-        source_line_list_blob = options.source_line_list_blob_name,
-        byte_list_blob = options.byte_list_blob_name,
+        fn_attributes = options().fn_attributes,
+        decoded_input_blob = options().decoded_input_blob_name,
+        string_ptr_blob = options().string_ptr_blob_name,
+        source_line_list_blob = options().source_line_list_blob_name,
+        byte_list_blob = options().byte_list_blob_name,
     )
 }
