@@ -1,10 +1,10 @@
-use crate::{Options, NS as GLOBAL_NS};
+use crate::{options, NS as GLOBAL_NS};
 
 fn ns() -> String {
     format!("{}__error_level", GLOBAL_NS)
 }
 
-pub fn error_level(options: &Options) -> String {
+pub fn error_level() -> String {
     format!(
         "
 // ErrorLevel
@@ -15,7 +15,7 @@ bool {fn_attributes} {ns}__is_warning(const {error_level_blob} *self_blob);
 bool {fn_attributes} {ns}__is_error(const {error_level_blob} *self_blob);
 ",
         ns = ns(),
-        fn_attributes = options.fn_attributes,
-        error_level_blob = options.error_level_blob_name,
+        fn_attributes = options().fn_attributes,
+        error_level_blob = options().error_level_blob_name,
     )
 }
