@@ -1,10 +1,10 @@
-use crate::{Options, NS as GLOBAL_NS};
+use crate::{options, NS as GLOBAL_NS};
 
 fn ns() -> String {
     format!("{}__loc", GLOBAL_NS)
 }
 
-pub fn loc(options: &Options) -> String {
+pub fn loc() -> String {
     format!(
         "
 // Loc
@@ -14,7 +14,7 @@ uint64_t {fn_attributes} {ns}__get_begin(const {loc_blob} *self_blob);
 uint64_t {fn_attributes} {ns}__get_end(const {loc_blob} *self_blob);
 ",
         ns = ns(),
-        fn_attributes = options.fn_attributes,
-        loc_blob = options.loc_blob_name
+        fn_attributes = options().fn_attributes,
+        loc_blob = options().loc_blob_name
     )
 }
