@@ -1,5 +1,5 @@
 use crate::{helpers, options, NS as GLOBAL_NS};
-use lib_ruby_parser_nodes::template::*;
+use lib_ruby_parser_nodes::{template::*, Message, MessageField};
 
 const TEMPLATE: &str = "
 // DiagnosticMessage
@@ -30,28 +30,28 @@ void {{ helper fn-attributes }} {{ helper ns }}__diagnostic_message__drop({{ hel
 pub fn message() -> String {
     let template = TemplateRoot::new(TEMPLATE).unwrap();
     let mut fns = TemplateFns::new();
-    fns.register_helper("message-constructor", helpers::messages::constructor::sig);
-    fns.register_helper("variant-getter", helpers::messages::variant_getter::sig);
-    fns.register_helper(
+    fns.register::<Message, F::Helper>("message-constructor", helpers::messages::constructor::sig);
+    fns.register::<Message, F::Helper>("variant-getter", helpers::messages::variant_getter::sig);
+    fns.register::<Message, F::Helper>(
         "variant-predicate",
         helpers::messages::variant_predicate::sig,
     );
-    fns.register_helper("field-getter", helpers::messages::field_getter::sig);
+    fns.register::<MessageField, F::Helper>("field-getter", helpers::messages::field_getter::sig);
 
     fn fn_attributes(_: &GlobalContext) -> String {
         options().fn_attributes.to_string()
     }
-    fns.register_helper("fn-attributes", fn_attributes);
+    fns.register::<GlobalContext, F::Helper>("fn-attributes", fn_attributes);
 
     fn ns(_: &GlobalContext) -> String {
         GLOBAL_NS.to_string()
     }
-    fns.register_helper("ns", ns);
+    fns.register::<GlobalContext, F::Helper>("ns", ns);
 
     fn message_blob(_: &GlobalContext) -> String {
         options().diagnostic_message_blob_name.to_string()
     }
-    fns.register_helper("message-blob", message_blob);
+    fns.register::<GlobalContext, F::Helper>("message-blob", message_blob);
 
     template.render(ALL_DATA, &fns)
 }
