@@ -1,5 +1,5 @@
 use crate::{helpers, options, NS as GLOBAL_NS};
-use lib_ruby_parser_nodes::template::*;
+use lib_ruby_parser_nodes::{template::*, Node, NodeField};
 
 const TEMPLATE: &str = "
 // Node
@@ -66,36 +66,36 @@ void {{ helper fn-attributes }} {{ helper ns }}__node__drop({{ helper node-blob
 pub fn node() -> String {
     let template = TemplateRoot::new(TEMPLATE).unwrap();
     let mut fns = TemplateFns::new();
-    fns.register_helper("node-constructor", helpers::nodes::constructor::sig);
-    fns.register_helper(
+    fns.register::<Node, F::Helper>("node-constructor", helpers::nodes::constructor::sig);
+    fns.register::<Node, F::Helper>(
         "node-variant-predicate",
         helpers::nodes::variant_predicate::sig,
     );
-    fns.register_helper("node-variant-getter", helpers::nodes::variant_getter::sig);
-    fns.register_helper("node-field-getter", helpers::nodes::field_getter::sig);
-    fns.register_helper("node-field-setter", helpers::nodes::field_setter::sig);
-    fns.register_helper(
+    fns.register::<Node, F::Helper>("node-variant-getter", helpers::nodes::variant_getter::sig);
+    fns.register::<NodeField, F::Helper>("node-field-getter", helpers::nodes::field_getter::sig);
+    fns.register::<NodeField, F::Helper>("node-field-setter", helpers::nodes::field_setter::sig);
+    fns.register::<Node, F::Helper>(
         "internal-struct-definition",
         helpers::nodes::internal_struct::definition,
     );
-    fns.register_helper("into-variant", helpers::nodes::into_variant::sig);
-    fns.register_helper("into-internal", helpers::nodes::into_internal::sig);
-    fns.register_helper("drop-variant", helpers::nodes::drop_variant::sig);
+    fns.register::<Node, F::Helper>("into-variant", helpers::nodes::into_variant::sig);
+    fns.register::<Node, F::Helper>("into-internal", helpers::nodes::into_internal::sig);
+    fns.register::<Node, F::Helper>("drop-variant", helpers::nodes::drop_variant::sig);
 
     fn fn_attributes(_: &GlobalContext) -> String {
         options().fn_attributes.to_string()
     }
-    fns.register_helper("fn-attributes", fn_attributes);
+    fns.register::<GlobalContext, F::Helper>("fn-attributes", fn_attributes);
 
     fn ns(_: &GlobalContext) -> String {
         GLOBAL_NS.to_string()
     }
-    fns.register_helper("ns", ns);
+    fns.register::<GlobalContext, F::Helper>("ns", ns);
 
     fn node_blob(_: &GlobalContext) -> String {
         options().node_blob_name.to_string()
     }
-    fns.register_helper("node-blob", node_blob);
+    fns.register::<GlobalContext, F::Helper>("node-blob", node_blob);
 
     template.render(ALL_DATA, &fns)
 }
