@@ -1,10 +1,10 @@
-use crate::{Options, NS as GLOBAL_NS};
+use crate::{options, NS as GLOBAL_NS};
 
 fn ns() -> String {
     format!("{}__parser_result", GLOBAL_NS)
 }
 
-pub fn parser_result(options: &Options) -> String {
+pub fn parser_result() -> String {
     format!(
         "
 // ParserResult
@@ -24,13 +24,13 @@ const {magic_comment_list_blob} *{fn_attributes} {ns}__get_magic_comments(const
 const {decoded_input_blob} *{fn_attributes} {ns}__get_input(const {parser_result_blob} *self_blob);
 ",
         ns = ns(),
-        fn_attributes = options.fn_attributes,
-        parser_result_blob = options.parser_result_blob_name,
-        maybe_ptr_blob = options.maybe_ptr_blob_name,
-        token_list_blob = options.token_list_blob_name,
-        diagnostic_list_blob = options.diagnostic_list_blob_name,
-        comment_list_blob = options.comment_list_blob_name,
-        magic_comment_list_blob = options.magic_comment_list_blob_name,
-        decoded_input_blob = options.decoded_input_blob_name,
+        fn_attributes = options().fn_attributes,
+        parser_result_blob = options().parser_result_blob_name,
+        maybe_ptr_blob = options().maybe_ptr_blob_name,
+        token_list_blob = options().token_list_blob_name,
+        diagnostic_list_blob = options().diagnostic_list_blob_name,
+        comment_list_blob = options().comment_list_blob_name,
+        magic_comment_list_blob = options().magic_comment_list_blob_name,
+        decoded_input_blob = options().decoded_input_blob_name,
     )
 }
