@@ -1,10 +1,10 @@
-use crate::{Options, NS as GLOBAL_NS};
+use crate::{options, NS as GLOBAL_NS};
 
 fn ns() -> String {
     format!("{}__ptr", GLOBAL_NS)
 }
 
-pub fn ptr(options: &Options) -> String {
+pub fn ptr() -> String {
     format!(
         "
 // Ptr
@@ -15,7 +15,7 @@ const void *{fn_attributes} {ns}__get_raw(const {ptr_blob} *self_blob);
 void *{fn_attributes} {ns}__into_raw({ptr_blob} self_blob);
 ",
         ns = ns(),
-        fn_attributes = options.fn_attributes,
-        ptr_blob = options.ptr_blob_name
+        fn_attributes = options().fn_attributes,
+        ptr_blob = options().ptr_blob_name
     )
 }
