@@ -1,10 +1,10 @@
-use crate::{Options, NS as GLOBAL_NS};
+use crate::{options, NS as GLOBAL_NS};
 
 fn ns() -> String {
     format!("{}__shared_byte_list", GLOBAL_NS)
 }
 
-pub fn shared_byte_list(options: &Options) -> String {
+pub fn shared_byte_list() -> String {
     format!(
         "
 // SharedByteList
@@ -14,7 +14,7 @@ const uint8_t *{fn_attributes} {ns}__get_raw(const {shared_byte_list_blob} *self
 uint64_t {fn_attributes} {ns}__get_len(const {shared_byte_list_blob} *self_blob);
 ",
         ns = ns(),
-        fn_attributes = options.fn_attributes,
-        shared_byte_list_blob = options.shared_byte_list_blob_name
+        fn_attributes = options().fn_attributes,
+        shared_byte_list_blob = options().shared_byte_list_blob_name
     )
 }
