@@ -1,10 +1,10 @@
-use crate::{Options, NS as GLOBAL_NS};
+use crate::{options, NS as GLOBAL_NS};
 
 fn ns() -> String {
     format!("{}__source_line", GLOBAL_NS)
 }
 
-pub fn source_line(options: &Options) -> String {
+pub fn source_line() -> String {
     format!(
         "
 // SourceLine
@@ -18,7 +18,7 @@ void {fn_attributes} {ns}__set_end({source_line_blob} *self_blob, uint64_t end);
 void {fn_attributes} {ns}__set_ends_with_eof({source_line_blob} *self_blob, bool ends_with_eof);
 ",
         ns = ns(),
-        fn_attributes = options.fn_attributes,
-        source_line_blob = options.source_line_blob_name
+        fn_attributes = options().fn_attributes,
+        source_line_blob = options().source_line_blob_name
     )
 }
