@@ -1,10 +1,10 @@
-use crate::{Options, NS as GLOBAL_NS};
+use crate::{options, NS as GLOBAL_NS};
 
 fn ns() -> String {
     format!("{}__string_ptr", GLOBAL_NS)
 }
 
-pub fn string_ptr(options: &Options) -> String {
+pub fn string_ptr() -> String {
     format!(
         "
 // StringPtr
@@ -15,7 +15,7 @@ uint8_t *{fn_attributes} {ns}__into_raw({string_ptr_blob} self_blob);
 uint64_t {fn_attributes} {ns}__get_len(const {string_ptr_blob} *self_blob);
 ",
         ns = ns(),
-        fn_attributes = options.fn_attributes,
-        string_ptr_blob = options.string_ptr_blob_name
+        fn_attributes = options().fn_attributes,
+        string_ptr_blob = options().string_ptr_blob_name
     )
 }
