@@ -14,6 +14,7 @@ pub fn name(message: &Message) -> String {
 fn arglist(message: &Message) -> String {
     message
         .fields
+        .iter()
         .map(|field| {
             format!(
                 "{field_type} {field_name}_blob",
@@ -21,6 +22,7 @@ fn arglist(message: &Message) -> String {
                 field_name = fields::field_name(field)
             )
         })
+        .collect::<Vec<_>>()
         .join(", ")
 }
 
