@@ -9,6 +9,7 @@ pub fn name(node: &Node) -> String {
 
 fn arglist(node: &Node) -> String {
     node.fields
+        .iter()
         .map(|field| {
             format!(
                 "{field_type} {name}_blob",
@@ -16,6 +17,7 @@ fn arglist(node: &Node) -> String {
                 name = fields::field_name(field)
             )
         })
+        .collect::<Vec<_>>()
         .join(", ")
 }
 
