@@ -8,13 +8,17 @@ pub fn name(node: &Node) -> String {
 
 /// Returns definition of the internal struct representing given `node`
 pub fn definition(node: &Node) -> String {
-    let fields = node.fields.map(|field| {
-        format!(
-            "{} {};",
-            fields::field_type(field),
-            fields::field_name(field)
-        )
-    });
+    let fields = node
+        .fields
+        .iter()
+        .map(|field| {
+            format!(
+                "{} {};",
+                fields::field_type(field),
+                fields::field_name(field)
+            )
+        })
+        .collect::<Vec<_>>();
 
     format!(
         "typedef struct {internal_struct_name}
