@@ -1,5 +1,5 @@
 use super::{internal_struct, ns};
-use crate::Options;
+use crate::options;
 use lib_ruby_parser_nodes::Node;
 
 /// Returns name of the cast-into-internal fn for the given `node`
@@ -12,12 +12,12 @@ pub fn name(node: &Node) -> String {
 }
 
 /// Returns C signature of the cast-into-internal fn for the given `node`
-pub fn sig(node: &Node, options: &Options) -> String {
+pub fn sig(node: &Node) -> String {
     format!(
         "{internal_struct_name} {fn_attributes} {fn_name}({node_variant_blob} self_blob)",
         internal_struct_name = internal_struct::name(node),
-        fn_attributes = options.fn_attributes,
-        node_variant_blob = options.node_variant_blob_name(node),
+        fn_attributes = options().fn_attributes,
+        node_variant_blob = options().node_variant_blob_name(node),
         fn_name = name(node)
     )
 }
