@@ -1,5 +1,5 @@
 use super::ns;
-use crate::Options;
+use crate::options;
 use lib_ruby_parser_nodes::Node;
 
 /// Returns name of the cast-to-variant function for the given `node`
@@ -8,12 +8,12 @@ pub fn name(node: &Node) -> String {
 }
 
 /// Returns name of the cast-to-variant function for the given `node`
-pub fn sig(node: &Node, options: &Options) -> String {
+pub fn sig(node: &Node) -> String {
     format!(
         "{node_variant_blob} *{fn_attributes} {variant_getter_name}({node_blob} *self_blob)",
-        node_variant_blob = options.node_variant_blob_name(node),
-        fn_attributes = options.fn_attributes,
+        node_variant_blob = options().node_variant_blob_name(node),
+        fn_attributes = options().fn_attributes,
         variant_getter_name = name(node),
-        node_blob = options.node_blob_name
+        node_blob = options().node_blob_name
     )
 }
