@@ -1,5 +1,5 @@
 use super::ns;
-use crate::Options;
+use crate::options;
 use lib_ruby_parser_nodes::Node;
 
 /// Returns name of the is-a-variant function for the given `node`
@@ -8,11 +8,11 @@ pub fn name(node: &Node) -> String {
 }
 
 /// Returns name of the is-a-variant function for the given `node`
-pub fn sig(node: &Node, options: &Options) -> String {
+pub fn sig(node: &Node) -> String {
     format!(
         "bool {fn_attributes} {variant_predicate_name}(const {node_blob}* self_blob)",
-        fn_attributes = options.fn_attributes,
+        fn_attributes = options().fn_attributes,
         variant_predicate_name = name(node),
-        node_blob = options.node_blob_name
+        node_blob = options().node_blob_name
     )
 }
