@@ -28,22 +28,26 @@ fn test_generate() {
 
 fn message_stubs_h(options: &Options) -> String {
     lib_ruby_parser_nodes::messages()
+        .iter()
         .map(|message| {
             format!(
                 "typedef struct {{}} {};",
                 options.message_variant_blob_name(message)
             )
         })
+        .collect::<Vec<_>>()
         .join("\n")
 }
 
 fn node_stubs_h(options: &Options) -> String {
     lib_ruby_parser_nodes::nodes()
+        .iter()
         .map(|node| {
             format!(
                 "typedef struct {{}} {};",
                 options.node_variant_blob_name(node)
             )
         })
+        .collect::<Vec<_>>()
         .join("\n")
 }
